@@ -889,12 +889,9 @@ function loadMediaSessionsShim() {
             const tagName = arguments[0];
 
             if (typeof tagName === "string") {
-                if (tagName.toLowerCase() === "audio") {
+                if (tagName.toLowerCase() === "audio" || tagName.toLowerCase() === "video") {
                     const player = createdTag;
                     ${addPlayerToDomEvadingAutoPlayBlocking}
-                } else if (tagName.toLowerCase() === "video") {
-                    (document.head || document.documentElement).appendChild(createdTag);
-                    createdTag.parentNode.removeChild(createdTag);
                 }
             }
         `;
